import { AxiosInstance } from 'axios';
import { Builder } from '../helpers/Builder';
import { ApiResponse } from '../models/ApiResponse';
import { IWebsocketClient } from './websocket/websocket-client';
export declare class LegalAnalyticsClient {
    private timer;
    private apiKey;
    private apiEndpoint;
    private readonly restClient;
    private readonly websocketClient;
    private connectionId;
    private analyzeTaskPromises;
    /**
     * Creates and configures RestApi and WebsocketApi client with given apiKey as authorization.
     *
     * @param websocketClient Client to use for socket connection
     * @param restClient Client to access Legal Analytics Rest Api
     */
    constructor(websocketClient: IWebsocketClient, restClient: AxiosInstance, apiKey: string, endpoint: string);
    /**
     * Analyze given data with JuracusAI
     *
     * @param dataFormat Format of the provided file data.
     * @param data       Data of the file to analyze. Can be provided as base64 String or Buffer. You can find the supported file types here: {@link DataFormat}.
     * @param criteria   {@link Collection} of criteria to analyze.
     * @param criteriaListWithOptions   {@link Collection} of criteria to analyze with Options.
     * @param language   Language with which the contract is analyzed.
     * @param smartSearchTasks Smart Search Tasks that are passed on to the Ki during the analysis job.
     * @return response  Response as Promise with which you can access the Analysis response asynchronously.
     */
    readonly analyzeAsync: (builder: Builder) => Promise<ApiResponse>;
    getUuid(): string;
    private delay;
    /**
     * Gets called when Websocket message is sent from the server. Executes analysis when ConnectionId is delivered,
     * and completes analysis when done
     *
     * @param event Received message from server in format {@link UpdateMessage}
     */
    private readonly handleWebsocketMessage;
    private getResponseJson;
    private readonly maintainWebsocketConnection;
    /**
     * Sends request to get connectionId and maintains connection by sending heartbeat request every 4 minutes
     * @param event {@link OpenEvent}
     */
    private readonly sendConnectionIdRequestOnOpen;
    private readonly handleOnClose;
    private readonly handleOnError;
    private ensureUpload;
    private getUploadLink;
    private readonly uploadWithPresignedUrl;
    private readonly postApiRequest;
    close(): void;
}
