import { Language } from '../LegalAnalyticsClient/websocket/Language';
import { CriterionFilterType } from './CriterionFilterType';
/**
 * A {@link Criterion} defines what the Juracus AI has to analyze. For each {@link Criterion} there is a short name {@link #name} and description.
 *
 * @author Onur Gürsoy
 */
export declare class Criterion {
    readonly id: string;
    readonly categoryId: string;
    readonly name: Map<Language, string>;
    readonly description: Map<Language, string>;
    readonly available: boolean;
    readonly criterionLanguages: Set<Language>;
    readonly availableFilters: Set<CriterionFilterType>;
    /**
     *  Data erasure and data return
     */
    static readonly DATA_DELETION_AND_RETURN: Criterion;
    /**
     * Data transfer to third parties
     */
    static readonly DATA_TRANSFER_TO_THIRD_PARTIES: Criterion;
    /**
     *  Data transfer to otherwise authorized third parties
     */
    static readonly DATA_TRANSFER_TO_OTHERWISE_AUTHORIZED_THIRD_PARTIES: Criterion;
    /**
     *  Data transfer to partner companies
     */
    static readonly DATA_TRANSFER_TO_PARTNER_COMPANY: Criterion;
    /**
     * Data transfer and usage for an agreed purpose
     */
    static readonly DATA_TRANSFER_FOR_AGGREED_PURPOSE: Criterion;
    /**
     *  Deadlines
     */
    static readonly DEADLINES: Criterion;
    /**
     * Fines
     */
    static readonly FINES: Criterion;
    /**
     *  Regulations regarding the jurisdiction
     */
    static readonly JURISDICTION_REGULATIONS: Criterion;
    /**
     * Force Majeure
     */
    static readonly FORCE_MAJEURE: Criterion;
    /**
     * Definition of 'information'
     */
    static readonly DEFINITION_OF_INFORMATION: Criterion;
    /**
     * Change of Control
     */
    static readonly CHANGE_OF_CONTROL: Criterion;
    /**
     * Terms
     */
    static readonly TERMS: Criterion;
    /**
     * Regulations regarding loopholes
     */
    static readonly LOOPHOLES: Criterion;
    /**
     * Regulations regarding ordinary jurisdiction
     */
    static readonly ORDINARIY_JURISDICTION: Criterion;
    /**
     * Preamble and objectives of the contract
     */
    static readonly PREAMBLE: Criterion;
    /**
     * Regulations regarding arbitration
     */
    static readonly ARBITRATION: Criterion;
    /**
     * Regulations regarding the cancellation of the contract
     */
    static readonly CONTRACT_CANCELLATION: Criterion;
    /**
     * Contractual claims in the even of breach of contract
     */
    static readonly CONTRACTUAL_CLAIMS_BREACH_OF_CONTRACT: Criterion;
    static readonly PERIOD_OF_NOTICE: Criterion;
    static readonly REVOCATION_INFORMATION: Criterion;
    static readonly DELIVERY_TERMS: Criterion;
    static readonly EXCLUSION_OF_IPR_AND_UN_SALES_LAW: Criterion;
    static readonly JURISDICTION_TYPE: Criterion;
    static readonly PLACE_OF_JURISDICTION: Criterion;
    static readonly RETENTION_OF_TITLE_FOR_DELIVERY_ITEMS: Criterion;
    static readonly LIMITATION_OF_LIABILITY: Criterion;
    static readonly RETENTION_OF_TITLE: Criterion;
    static readonly CONFIDENTIALITY_OBLIGATIONS_OF_ANY_KIND: Criterion;
    static readonly FORM_REQUIREMENT: Criterion;
    static readonly COMPENSATION: Criterion;
    static readonly AUTOMATIC_CONTRACT_EXTENSION: Criterion;
    static readonly RENTAL_COLLATERAL: Criterion;
    static readonly EXTENSION_OPTION: Criterion;
    /**
     * Returns the criterion that has the supplied id.
     * @param {string} id The id of the criterion that is searched.
     * @return {*}  {(Criterion | null)} The Criterion with the supplied id or null if there was no criterion found with this ID.
     * @memberof Criterion
     */
    static getCriterionById(id: string): Criterion | null;
    /**
     * Constructs a new {@link Criterion} with the specified parameters.
     *
     * @param id                  - UUID of the {@link Criterion}.
     * @param categoryId          - UUID of the {@link Criterion}'s category.
     * @param name                - Name of the {@link Criterion}.
     * @param description         - Detailed description of the {@link Criterion}.
     * @param available           - Flag specifying for which services the {@link Criterion} is available.
     * @param criterionLanguages  - Set of languages for which the {@link Criterion} is available.
     */
    private constructor();
    getName(language: Language): string;
}
