import { ApiMetadata } from './ApiMetadata';
import { GData } from './GData';
import { MetaDataEntity } from './MetaDataEntity';
import { TextSpan } from './TextSpan';
/**
 * Juracus SmartSearchResult for a specific SmartSearchTask.
 *
 * @author Sven Wensing
 */
export declare class SmartSearchResult {
    readonly identifier: string;
    readonly span: TextSpan;
    readonly text: string;
    readonly geom: GData;
    readonly metadata: {
        [p: string]: ApiMetadata<MetaDataEntity>;
    };
    readonly id: string;
    /**
     * Constructs a new {@link AnalysisResults} object containing the analysis results for the specified criterion.
     *
     * @param pId - UUID of the {@link Criterion} the result belongs to.
     * @param clauses     - {@link Array} of analyzed texts. Defaults to an empty {@link Array} if {@code null}.
     * @param foundFlag   - {@link Boolean} specifying whether or not at least one as relevant classified clause was found.
     * @param metadata    - {@link Map} for additional metadata. Defaults to an empty {@link Map} if {@code null}.
     * @param geom     - {@link GData } contains Geometric data of the Smartsearchresult.
     */
    constructor(pid: string, identifier: string, span: TextSpan, text: string, geom: GData, metadata: {
        [p: string]: ApiMetadata<MetaDataEntity>;
    });
    /**
     * Returns the {@link ApiCriterionMetadataKey}s for which contents are available.
     *
     * @return {@link Set} of {@link ApiCriterionMetadataKey}s for which contents are available.
     */
    readonly availableMetadataKeys: () => string[];
}
