import { ApiResponse } from './ApiResponse';
import { Criterion } from './Criterion';
/**
 * Groups the analysis results of multiple criteria into one object.
 * The clause texts for this group are deferred from the ApiResponse and deduplicated
 * automatically upon instantiation of an AnalysisResultGroup object.
 * The found flag is set automatically set if clauses were found for this group.
 * @param apiResponse - An {@link ApiResponse} that contains analysis results that should be grouped.
 * @param criteria - An Array of {@link Criterion} that determine which criteria belong to this group.
 * @param name - A {@link string} that specifies the name of this group.
 */
export declare class AnalysisResultGroup {
    readonly apiResponse: ApiResponse;
    readonly criteria: Array<Criterion>;
    readonly name: string;
    readonly clauseTexts: Array<string>;
    readonly foundFlag: boolean;
    constructor(apiResponse: ApiResponse, criteria: Array<Criterion>, name: string);
    /**
     * Gets all clause texts from all results of every criterion and deduplicates them so that each clause text only exists once per AnalysisResultGroup.
     * @memberof AnalysisResultGroup
     */
    getDeduplicatedClauseTexts: (criteria: Array<Criterion>, apiResponse: ApiResponse) => any[];
    /**
     * Determines if any results were found for this AnalysisResultGroup. An AnalysisResultGroup is considered if there exists a result text for any of its criteria.
     * @memberof AnalysisResultGroup
     */
    getFoundFlag: (criteria: Array<Criterion>, apiResponse: ApiResponse) => boolean;
}
